; Marble/theme.jl

;; Copyright (C) 1999 Jesus Bravo Alvarez <jba@pobox.com>

;; This theme is based on the Marble enlightenment theme created by
;; Matthew Kirsch <kirsch@kirsch.cx>.


;; The font

(defvar Marble:font "-*-lucida-bold-r-normal-*-*-100-*-*-p-*-iso8859-1")


;; Images

(defvar Marble:title-images (list (make-image "title-bar-inactive.png")
                                  (make-image "title-bar-active.png")))

(defvar Marble:s-title-images (list 
         (set-image-border (make-image "s-title-bar-inactive.png") 5 5 0 0)
         (set-image-border (make-image "s-title-bar-active.png") 5 5 0 0)))

(defvar Marble:iconify-images (list (make-image "iconify-normal.png")
                                     nil nil
                                    (make-image "iconify-clicked.png")))

(defvar Marble:maximize-images (list (make-image "maximize-normal.png")
                                      nil nil
                                     (make-image "maximize-clicked.png")))

(defvar Marble:close-images (list (make-image "close-normal.png")
                                   nil nil
                                  (make-image "close-clicked.png")))

(defvar Marble:menu-images (list (make-image "menu-inactive.png")
                                 (make-image "menu-active-normal.png") nil
                                 (make-image "menu-active-clicked.png")))

(defvar Marble:horizontal-border-images (make-image "hor-border.png"))
(defvar Marble:vertical-border-images (make-image "ver-border.png"))

(defvar Marble:corner-images (make-image "corner.png"))


;; frame layout

(defvar Marble:frame
  `(
    ;; title
     ((background . ,Marble:title-images)
      (foreground . ("black" "white"))
      (font . ,Marble:font)
      (text . window-name)
      (x-justify . 4)
      (y-justify . center)
      (top-edge . -15)
      (left-edge . 21)
      (right-edge . 42)
      (class . title))

    ;; menu button
     ((background . ,Marble:menu-images)
      (top-edge . -15)
      (left-edge . 0)
      (class . menu-button))

    ;; iconify button
     ((background . ,Marble:iconify-images)
      (top-edge . -15)
      (right-edge . 29)
      (class . iconify-button))

    ;; maximize button
     ((background . ,Marble:maximize-images)
      (top-edge . -15)
      (right-edge . 15)
      (class . maximize-button))

    ;; close button
     ((background . ,Marble:close-images)
      (top-edge . -15)
      (right-edge . 0)
      (class . close-button))

    ;; left border
     ((background . ,Marble:vertical-border-images)
      (top-edge . -15)
      (bottom-edge . 0)
      (left-edge . -4)
      (class . left-border))

    ;; right border
     ((background . ,Marble:vertical-border-images)
      (top-edge . -15)
      (bottom-edge . 0)
      (right-edge . -4)
      (class . right-border))

    ;; top border
     ((background . ,Marble:horizontal-border-images)
      (top-edge . -19)
      (right-edge . 0)
      (left-edge . 0)
      (class . top-border))

    ;; bottom border
     ((background . ,Marble:horizontal-border-images)
      (bottom-edge . -4)
      (right-edge . 0)
      (left-edge . 0)
      (class . bottom-border))

    ;; top-left corner
     ((background . ,Marble:corner-images)
      (top-edge . -19)
      (left-edge . -4)
      (class . top-left-corner))

    ;; top-right corner
     ((background . ,Marble:corner-images)
      (top-edge . -19)
      (right-edge . -4)
      (class . top-right-corner))

    ;; bottom-left corner
     ((background . ,Marble:corner-images)
      (bottom-edge . -4)
      (left-edge . -4)
      (class . bottom-left-corner))

    ;; bottom-right corner
     ((background . ,Marble:corner-images)
      (bottom-edge . -4)
      (right-edge . -4)
      (class . bottom-right-corner))
))

(defvar Marble:shaped-frame
  `(
    ;; title out
     ((background . ,Marble:s-title-images)
      (top-edge . -19)
      (left-edge . -4)
      (right-edge . -4)
      (class . title))

    ;; title in
     ((background . ,Marble:title-images)
      (foreground . ("black" "white"))
      (font . ,Marble:font)
      (text . window-name)
      (x-justify . 4)
      (y-justify . center)
      (top-edge . -15)
      (left-edge . 21)
      (right-edge . 42)
      (class . title))

    ;; menu button
     ((background . ,Marble:menu-images)
      (top-edge . -15)
      (left-edge . 0)
      (class . menu-button))

    ;; iconify button
     ((background . ,Marble:iconify-images)
      (top-edge . -15)
      (right-edge . 29)
      (class . iconify-button))

    ;; maximize button
     ((background . ,Marble:maximize-images)
      (top-edge . -15)
      (right-edge . 15)
      (class . maximize-button))

    ;; close button
     ((background . ,Marble:close-images)
      (top-edge . -15)
      (right-edge . 0)
      (class . close-button))
))

(defvar Marble:transient-frame
  `(
    ;; title out
      ((background . ,Marble:s-title-images)
       (top-edge . -23)
       (left-edge . 0)
       (right-edge . 0)
       (class . title))

    ;; title in
      ((background . ,Marble:title-images)
       (foreground . ("black" "white"))
       (font . ,Marble:font)
       (text . window-name)
       (x-justify . 4)
       (y-justify . center)
       (top-edge . -19)
       (left-edge . 25)
       (right-edge . 19)
       (class . title))

    ;; menu button
      ((background . ,Marble:menu-images)
      (top-edge . -19)
      (left-edge . 4)
      (class . menu-button))

    ;; close button
     ((background . ,Marble:close-images)
      (top-edge . -19)
      (right-edge . 4)
      (class . close-button))
))


;; Frame definition

(defun Marble:frame-style (w type)
  (cond ((eq type 'unframed) 'nil-frame)
        ((eq type 'shaped) 'Marble:shaped-frame)
        ((eq type 'transient) 'Marble:transient-frame)
        ((eq type 'shaped-transient) 'Marble:transient-frame)
        (t 'Marble:frame)))

(add-frame-style 'Marble 'Marble:frame-style)

